@@ -6,6 +6,8 @@
 
 #include "FaceLoader.h"
 
+#include "PageController.h"
+
 using namespace Qt::StringLiterals;
 using namespace KSysGuard;
 
@@ -68,7 +70,7 @@ void FaceLoader::setDataObject(PageDataObject *newDataObject)
         }
 
         if (!m_faceController) {
-            auto configGroup = m_dataObject->config()->group(faceConfig);
+            auto configGroup = m_dataObject->controller()->config()->group(faceConfig);
             m_faceController = new SensorFaceController(configGroup, qmlEngine(this), qmlEngine(this));
             m_faceController->setShouldSync(false);
             s_faceCache.insert(cacheName, m_faceController);
@@ -76,10 +78,12 @@ void FaceLoader::setDataObject(PageDataObject *newDataObject)
 
         connect(m_faceController, &SensorFaceController::faceIdChanged, m_dataObject, &PageDataObject::markDirty);
         connect(m_faceController, &SensorFaceController::titleChanged, m_dataObject, &PageDataObject::markDirty);
+        connect(m_faceController, &SensorFaceController::showTitleChanged, m_dataObject, &PageDataObject::markDirty);
         connect(m_faceController, &SensorFaceController::totalSensorsChanged, m_dataObject, &PageDataObject::markDirty);
         connect(m_faceController, &SensorFaceController::highPrioritySensorIdsChanged, m_dataObject, &PageDataObject::markDirty);
         connect(m_faceController, &SensorFaceController::lowPrioritySensorIdsChanged, m_dataObject, &PageDataObject::markDirty);
         connect(m_faceController, &SensorFaceController::sensorColorsChanged, m_dataObject, &PageDataObject::markDirty);
+        connect(m_faceController, &SensorFaceController::sensorLabelsChanged, m_dataObject, &PageDataObject::markDirty);
         connect(m_faceController, &SensorFaceController::updateRateLimitChanged, m_dataObject, &PageDataObject::markDirty);
 
         Q_EMIT controllerChanged();
@@ -98,6 +102,16 @@ SensorFaceController *FaceLoader::controller() const
     return m_faceController;
 }
 
+void FaceLoader::save(const KConfigBase &config)
+{
+    if (!m_faceController) {
+        return;
+    }
+
+    auto toGroup = config.group(m_dataObject->value(u"face"_s).toString());
+    PageController::copyGroupContents(m_faceController->configGroup(), toGroup);
+}
+
 void FaceLoader::reset()
 {
     auto faceConfig = m_dataObject->value(QStringLiteral("face")).toString();
@@ -114,4 +128,13 @@ void FaceLoader::reset()
     m_faceController = nullptr;
 }
 
+bool FaceLoader::forceSaveOnDestroy() const
+{
+    if (!m_faceController) {
+        return false;
+    }
+
+    return m_faceController->forceSaveOnDestroy();
+}
+
 #include "moc_FaceLoader.cpp"
